@@ -1,6 +1,6 @@
 =head1 Name
 
-Math::Cartesian::Product - Generate the cartesian product of zero or more lists.
+Math::Cartesian::Product - Generate the Cartesian product of zero or more lists.
 
 =head1 Synopsis
 
@@ -31,11 +31,11 @@ package Math::Cartesian::Product;
 use Carp;
 use strict;
 
-sub cartesian(&@)      # Generate the cartesian product of zero or more lists
+sub cartesian(&@)      # Generate the Cartesian product of zero or more lists
  {my $s = shift;       # Subroutine to call to process each element of the product
 
   my @C = @_;          # Lists to be multiplied
-  my @c = ();          # Current element of cartesian product
+  my @c = ();          # Current element of Cartesian product
   my @P = ();          # Cartesian product
   my $n = 0;           # Number of elements in product
 
@@ -43,7 +43,7 @@ sub cartesian(&@)      # Generate the cartesian product of zero or more lists
 
   @C == grep {ref eq 'ARRAY'} @C or croak("Arrays of things required by cartesian");
 
-# Generate each cartesian product when there are no prior cartesian products.
+# Generate each Cartesian product when there are no prior Cartesian products.
 
   my $p; $p = sub  
    {if (@c < @C) 
@@ -59,7 +59,7 @@ sub cartesian(&@)      # Generate the cartesian product of zero or more lists
      }
    };
 
-# Generate each cartesian product allowing for prior cartesian products.
+# Generate each Cartesian product allowing for prior Cartesian products.
 
   my $q; $q = sub  
    {if (@c < @C) 
@@ -75,7 +75,7 @@ sub cartesian(&@)      # Generate the cartesian product of zero or more lists
      }
    };
 
-# Determine optimal method of forming cartesian products for this call
+# Determine optimal method of forming Cartesian products for this call
 
   if (grep {grep {ref eq __PACKAGE__} @$_} @C)
    {&$q
@@ -97,13 +97,13 @@ use vars qw(@ISA @EXPORT $VERSION);
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw(cartesian);
-$VERSION = '1.007'; # Monday 26 Jan 2015
+$VERSION = '1.008'; # Monday 26 Jan 2015
 
 =head1 Description
 
-Generate the cartesian product of zero or more lists.
+Generate the Cartesian product of zero or more lists.
 
-Given two lists, say: [a,b] and [1,2,3], the cartesian product is the
+Given two lists, say: [a,b] and [1,2,3], the Cartesian product is the
 set of all ordered pairs:
 
  (a,1), (a,2), (a,3), (b,1), (b,2), (b,3)
@@ -112,10 +112,15 @@ which select their first element from all the possibilities listed in
 the first list, and select their second element from all the
 possibilities in the second list.
 
-The idea can be generalized to n-tuples selected from n lists. In
-particular, the cartesian product of zero lists is the empty set, as is
-the cartesian product of any set of lists which contain a list with no
-elements.
+The idea can be generalized to n-tuples selected from n lists where all the 
+elements of the first list are combined with all the elements of the second 
+list, the results of which are then combined with all the member of the third
+list and so on over all the input lists.
+
+It should be noted that Cartesian product of one or more lists where one or 
+more of the lists are empty (representing the empty set) is the empty set 
+and thus has zero members; and that the Cartesian product of zero lists is a 
+set with exactly one member, namely the empty set.
 
 C<cartesian()> takes the following parameters:
 
@@ -128,7 +133,7 @@ C<cartesian()> function, otherwise false.
 C<cartesian()> returns an array of references to all the n-tuples
 selected by the code block supplied as parameter 1. 
 
-C<cartesian()> croaks if you try to form the cartesian product of
+C<cartesian()> croaks if you try to form the Cartesian product of
 something other than lists of things.
 
 The cartesian product of lists A,B,C is associative, that is: 
@@ -136,8 +141,8 @@ The cartesian product of lists A,B,C is associative, that is:
   (A X B) X C = A X (B X C)
 
 C<cartesian()> respects associativity by allowing you to include a
-cartesian product produced by an earlier call to C<cartesian()> in the
-set of lists whose cartesian product is to be formed, at the cost of a
+Cartesian product produced by an earlier call to C<cartesian()> in the
+set of lists whose Cartesian product is to be formed, at the cost of a
 performance penalty if this option is chosen.
 
   use Math::Cartesian::Product;
